/**
 * Configuration management for GATI MCP Server
 */
export interface GatiMCPConfig {
    backendUrl: string;
}
/**
 * Load configuration from environment variables
 */
export declare function loadConfig(): GatiMCPConfig;
/**
 * Validate configuration
 */
export declare function validateConfig(config: GatiMCPConfig): void;
//# sourceMappingURL=config.d.ts.map