/**
 * Database connection for SQLite
 */
import Database from 'better-sqlite3';
import { GatiMCPConfig } from '../config/config.js';
/**
 * Initialize database connection
 */
export declare function initializeDatabase(config: GatiMCPConfig): Database.Database;
/**
 * Get database instance
 */
export declare function getDatabase(): Database.Database;
/**
 * Close database connection
 */
export declare function closeDatabase(): void;
/**
 * Test database connection
 */
export declare function testConnection(): boolean;
//# sourceMappingURL=connection.d.ts.map