/**
 * MCP Tool implementations for GATI traces
 */
import { z } from 'zod';
/**
 * Tool: list_agents
 * Lists all agents with their statistics
 */
export declare const listAgentsTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
    handler: () => Promise<string>;
};
/**
 * Tool: get_agent_stats
 * Get detailed statistics for a specific agent
 */
export declare const getAgentStatsTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
    }, {
        agent_name: string;
    }>;
    handler: (args: {
        agent_name: string;
    }) => Promise<string>;
};
/**
 * Tool: list_runs
 * List runs for a specific agent
 */
export declare const listRunsTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        limit: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        offset: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        limit: number;
        offset: number;
    }, {
        agent_name: string;
        limit?: number | undefined;
        offset?: number | undefined;
    }>;
    handler: (args: {
        agent_name: string;
        limit?: number;
        offset?: number;
    }) => Promise<string>;
};
/**
 * Tool: get_run_details
 * Get detailed information about a specific run
 */
export declare const getRunDetailsTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        run_name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        run_name: string;
    }, {
        agent_name: string;
        run_name: string;
    }>;
    handler: (args: {
        agent_name: string;
        run_name: string;
    }) => Promise<string>;
};
/**
 * Tool: get_run_timeline
 * Get chronological timeline of events for a run
 */
export declare const getRunTimelineTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        run_name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        run_name: string;
    }, {
        agent_name: string;
        run_name: string;
    }>;
    handler: (args: {
        agent_name: string;
        run_name: string;
    }) => Promise<string>;
};
/**
 * Tool: get_execution_trace
 * Get hierarchical execution trace showing parent-child relationships
 */
export declare const getExecutionTraceTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        run_name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        run_name: string;
    }, {
        agent_name: string;
        run_name: string;
    }>;
    handler: (args: {
        agent_name: string;
        run_name: string;
    }) => Promise<string>;
};
/**
 * Tool: compare_runs
 * Compare metrics across multiple runs
 */
export declare const compareRunsTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        run_names: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        run_names: string[];
    }, {
        agent_name: string;
        run_names: string[];
    }>;
    handler: (args: {
        agent_name: string;
        run_names: string[];
    }) => Promise<string>;
};
/**
 * Tool: search_events
 * Search events by various criteria
 */
export declare const searchEventsTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodOptional<z.ZodString>;
        event_type: z.ZodOptional<z.ZodString>;
        start_time: z.ZodOptional<z.ZodString>;
        end_time: z.ZodOptional<z.ZodString>;
        limit: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    }, "strip", z.ZodTypeAny, {
        limit: number;
        agent_name?: string | undefined;
        event_type?: string | undefined;
        start_time?: string | undefined;
        end_time?: string | undefined;
    }, {
        agent_name?: string | undefined;
        limit?: number | undefined;
        event_type?: string | undefined;
        start_time?: string | undefined;
        end_time?: string | undefined;
    }>;
    handler: (args: {
        agent_name?: string;
        event_type?: string;
        start_time?: string;
        end_time?: string;
        limit?: number;
    }) => Promise<string>;
};
/**
 * Tool: get_cost_breakdown
 * Get cost breakdown by model
 */
export declare const getCostBreakdownTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        agent_name?: string | undefined;
    }, {
        agent_name?: string | undefined;
    }>;
    handler: (args: {
        agent_name?: string;
    }) => Promise<string>;
};
/**
 * Tool: get_global_metrics
 * Get global metrics across all agents
 */
export declare const getGlobalMetricsTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
    handler: () => Promise<string>;
};
/**
 * Tool: get_event_details
 * Get full details of events including prompts and completions
 */
export declare const getEventDetailsTool: {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        run_name: z.ZodString;
        event_type: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        run_name: string;
        event_type?: string | undefined;
    }, {
        agent_name: string;
        run_name: string;
        event_type?: string | undefined;
    }>;
    handler: (args: {
        agent_name: string;
        run_name: string;
        event_type?: string;
    }) => Promise<string>;
};
/**
 * Export all tools
 */
export declare const allTools: ({
    name: string;
    description: string;
    inputSchema: z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
    handler: () => Promise<string>;
} | {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
    }, {
        agent_name: string;
    }>;
    handler: (args: {
        agent_name: string;
    }) => Promise<string>;
} | {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        limit: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        offset: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        limit: number;
        offset: number;
    }, {
        agent_name: string;
        limit?: number | undefined;
        offset?: number | undefined;
    }>;
    handler: (args: {
        agent_name: string;
        limit?: number;
        offset?: number;
    }) => Promise<string>;
} | {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        run_name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        run_name: string;
    }, {
        agent_name: string;
        run_name: string;
    }>;
    handler: (args: {
        agent_name: string;
        run_name: string;
    }) => Promise<string>;
} | {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        run_names: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        run_names: string[];
    }, {
        agent_name: string;
        run_names: string[];
    }>;
    handler: (args: {
        agent_name: string;
        run_names: string[];
    }) => Promise<string>;
} | {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodOptional<z.ZodString>;
        event_type: z.ZodOptional<z.ZodString>;
        start_time: z.ZodOptional<z.ZodString>;
        end_time: z.ZodOptional<z.ZodString>;
        limit: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    }, "strip", z.ZodTypeAny, {
        limit: number;
        agent_name?: string | undefined;
        event_type?: string | undefined;
        start_time?: string | undefined;
        end_time?: string | undefined;
    }, {
        agent_name?: string | undefined;
        limit?: number | undefined;
        event_type?: string | undefined;
        start_time?: string | undefined;
        end_time?: string | undefined;
    }>;
    handler: (args: {
        agent_name?: string;
        event_type?: string;
        start_time?: string;
        end_time?: string;
        limit?: number;
    }) => Promise<string>;
} | {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        agent_name?: string | undefined;
    }, {
        agent_name?: string | undefined;
    }>;
    handler: (args: {
        agent_name?: string;
    }) => Promise<string>;
} | {
    name: string;
    description: string;
    inputSchema: z.ZodObject<{
        agent_name: z.ZodString;
        run_name: z.ZodString;
        event_type: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        agent_name: string;
        run_name: string;
        event_type?: string | undefined;
    }, {
        agent_name: string;
        run_name: string;
        event_type?: string | undefined;
    }>;
    handler: (args: {
        agent_name: string;
        run_name: string;
        event_type?: string;
    }) => Promise<string>;
})[];
//# sourceMappingURL=tools.d.ts.map