#!/usr/bin/env node
/**
 * GATI MCP Server
 *
 * Model Context Protocol server for querying GATI traces from AI assistants
 * like Claude Desktop and GitHub Copilot.
 */
export {};
//# sourceMappingURL=index.d.ts.map