/**
 * Formatting utilities for LLM-friendly output
 */
import { AgentStats, RunDetails, Event } from '../api/client.js';
/**
 * Format agents list for LLM consumption
 */
export declare function formatAgentsList(agents: AgentStats[]): string;
/**
 * Format agent stats for LLM consumption
 */
export declare function formatAgentStats(agent: AgentStats): string;
/**
 * Format runs list for LLM consumption
 */
export declare function formatRunsList(runs: RunDetails[]): string;
/**
 * Format run details for LLM consumption
 */
export declare function formatRunDetails(run: RunDetails): string;
/**
 * Format timeline events for LLM consumption
 */
export declare function formatTimeline(events: Event[]): string;
/**
 * Format execution trace as tree for LLM consumption
 */
export declare function formatExecutionTrace(events: Event[]): string;
/**
 * Format comparison table for multiple runs
 */
export declare function formatRunComparison(runs: RunDetails[]): string;
/**
 * Format cost breakdown for LLM consumption
 */
export declare function formatCostBreakdown(breakdown: any[]): string;
/**
 * Format global metrics for LLM consumption
 */
export declare function formatGlobalMetrics(metrics: any): string;
//# sourceMappingURL=formatters.d.ts.map